@@ -1,5 +1,7 @@
-import ee
 import warnings
+
+import ee
+
 from .extending import extend
 
 
@@ -18,6 +20,17 @@ def __contains__(self, key):
     -------
     boolean
         Whether the key is contained in the dictionary.
+
+    Examples
+    --------
+    >>> import ee, eemont
+    >>> ee.Authenticate()
+    >>> ee.Initialize()
+    >>> eeDict = ee.Dictionary({"a":1,"b":2,"h":4})
+    >>> "a" in eeDict
+    True
+    >>> "c" in eeDict
+    False
     """
     return self.contains(key).getInfo()
 
@@ -37,5 +50,16 @@ def __getitem__(self, key):
     -------
     ee.Element
         Selected value.
+
+    Examples
+    --------
+    >>> import ee, eemont
+    >>> ee.Authenticate()
+    >>> ee.Initialize()
+    >>> eeDict = ee.Dictionary({"a":1,"b":2,"h":4})
+    >>> eeDict["a"].getInfo()
+    1
+    >>> eeDict["h"].getInfo()
+    4
     """
     return self.get(key)
