@@ -3,10 +3,10 @@ import warnings
 import ee
 import ee_extra
 import ee_extra.Spectral.core
+import ee_extra.Algorithms.core
 import numpy as np
 import requests
 
-from .common import _panSharpen
 from .extending import extend
 
 
@@ -100,9 +100,29 @@ def closest(self, date, tolerance=1, unit="month"):
 
     Examples
     --------
-    >>> import ee, eemont
-    >>> ee.Initialize()
-    >>> S2 = ee.ImageCollection('COPERNICUS/S2_SR').closest('2020-10-15')
+
+    .. tabs::
+
+        .. code-tab:: py
+
+            import ee, eemont
+            ee.Initialize()
+            S2 = ee.ImageCollection('COPERNICUS/S2_SR').closest('2020-10-15')
+
+        .. code-tab:: r R
+
+            library(rgee)
+            library(reticulate)
+            ee_Initialize()
+            eemont <- import("eemont")
+            S2 <- ee$ImageCollection('COPERNICUS/S2_SR')$closest('2020-10-15')
+
+        .. code-tab:: julia
+
+            using EarthEngine, PyCall
+            Initialize()
+            eemont = pyimport("eemont");
+            S2 = EE.ImageCollection("COPERNICUS/S2_SR") |> x -> closest(x,"2020-10-15");
     """
     return ee_extra.ImageCollection.core.closest(self, date, tolerance, unit)
 
@@ -454,26 +474,7 @@ def index(
         DeprecationWarning,
     )
 
-    return ee_extra.Spectral.core.spectralIndices(
-        self,
-        index,
-        G,
-        C1,
-        C2,
-        L,
-        cexp,
-        nexp,
-        alpha,
-        slope,
-        intercept,
-        gamma,
-        kernel,
-        sigma,
-        p,
-        c,
-        online,
-        drop,
-    )
+    return self
 
 
 @extend(ee.imagecollection.ImageCollection)
@@ -490,6 +491,8 @@ def spectralIndices(
     slope=1.0,
     intercept=0.0,
     gamma=1.0,
+    omega=2.0,
+    k=0.0,
     kernel="RBF",
     sigma="0.5 * (a + b)",
     p=2.0,
@@ -543,6 +546,10 @@ def spectralIndices(
         Soil line intercept.
     gamma : float, default = 1.0
         Weighting coefficient  used for ARVI.
+    omega : float, default = 2.0
+        Weighting coefficient  used for MBWI.
+    k : float, default = 0.0
+        Slope parameter by soil used for NIRvH2.
     kernel : str, default = 'RBF'
         Kernel used for kernel indices.\n
         Available options:
@@ -617,6 +624,8 @@ def spectralIndices(
         slope,
         intercept,
         gamma,
+        omega,
+        k,
         kernel,
         sigma,
         p,
@@ -1023,8 +1032,8 @@ def panSharpen(self, method="SFIM", qa=None, **kwargs):
         sharpening methods will produce different quality sharpening results in different
         scenarios.
     qa : str | list, default=None
-        One or more optional quality assessment names to apply after sharpening, e.g.
-        "MSE", "RASE", "UIQI", etc.
+        One or more optional quality assessment names to apply after sharpening. Results 
+        will be stored as image properties with the pattern `eemont:metric`, e.g. `eemont:RMSE`.
     **kwargs :
         Keyword arguments passed to ee.Image.reduceRegion() such as "geometry",
         "maxPixels", "bestEffort", etc. These arguments are only used for PCS sharpening
@@ -1044,7 +1053,7 @@ def panSharpen(self, method="SFIM", qa=None, **kwargs):
     >>> source = ee.ImageCollection("LANDSAT/LC08/C01/T1_TOA")
     >>> sharp = source.panSharpen(method="HPFA", qa=["MSE", "RMSE"], maxPixels=1e13)
     """
-    return _panSharpen(self, method, qa, **kwargs)
+    return ee_extra.Algorithms.core.panSharpen(img=self, method=method, qa=qa, prefix="eemont", **kwargs)
 
 
 @extend(ee.imagecollection.ImageCollection)
